==> tmdy_dll_0.0.0-031125.zip: TiMidity++-2.12.0-pre1b-031117-0200/libtimidity/playmidi_prv.h <==


static int play_midi_file(tmdy_struct_ex_t *tmdy_struct, char *fn);
static void dumb_pass_playing_list(tmdy_struct_ex_t *tmdy_struct, int number_of_files, char *list_of_files[]);
static void default_ctl_lyric(tmdy_struct_ex_t *tmdy_struct, int lyricid);
static int check_apply_control(tmdy_struct_ex_t *tmdy_struct);
static void recompute_freq(tmdy_struct_ex_t *tmdy_struct, int v);
static int midi_drumpart_change(tmdy_struct_ex_t *tmdy_struct, int ch, int isdrum);
static void ctl_note_event(tmdy_struct_ex_t *tmdy_struct, int noteID);
static void ctl_mode_event(tmdy_struct_ex_t *tmdy_struct, int type, int trace, long arg1, long arg2);
static char *channel_instrum_name(tmdy_struct_ex_t *tmdy_struct, int ch);
static int get_reverb_level(tmdy_struct_ex_t *tmdy_struct, int ch);
static int get_chorus_level(tmdy_struct_ex_t *tmdy_struct, int ch);
static void playmidi_output_changed(tmdy_struct_ex_t *tmdy_struct, int play_state);
static Instrument *play_midi_load_instrument(tmdy_struct_ex_t *tmdy_struct, int dr, int bk, int prog);
static void midi_program_change(tmdy_struct_ex_t *tmdy_struct, int ch, int prog);
static void free_voice(tmdy_struct_ex_t *tmdy_struct, int v);
static void play_midi_setup_drums(tmdy_struct_ex_t *tmdy_struct, int ch,int note);

/* For stream player */
static void playmidi_stream_init(tmdy_struct_ex_t *tmdy_struct);
static void playmidi_tmr_reset(tmdy_struct_ex_t *tmdy_struct);
static int play_event(tmdy_struct_ex_t *tmdy_struct, MidiEvent *ev);

static void dup_tone_bank_element(tmdy_struct_ex_t *tmdy_struct, int,int,int);
static void free_tone_bank_element(tmdy_struct_ex_t *tmdy_struct, int,int,int);

static void recompute_voice_filter(tmdy_struct_ex_t *tmdy_struct, int);
static int compute_data(tmdy_struct_ex_t *tmdy_struct, int32 count);

#define PM TMDY_PLAYMIDI

==> tmdy_dll_0.0.0-031126.zip: TiMidity++-2.12.0-pre1b-031117-0200/libtimidity/playmidi_prv.h <==


static int play_midi_file(tmdy_struct_ex_t *tmdy_struct, char *fn);
static void dumb_pass_playing_list(tmdy_struct_ex_t *tmdy_struct, int number_of_files, char *list_of_files[]);
static void default_ctl_lyric(tmdy_struct_ex_t *tmdy_struct, int lyricid);
static int check_apply_control(tmdy_struct_ex_t *tmdy_struct);
static void recompute_freq(tmdy_struct_ex_t *tmdy_struct, int v);
static int midi_drumpart_change(tmdy_struct_ex_t *tmdy_struct, int ch, int isdrum);
static void ctl_note_event(tmdy_struct_ex_t *tmdy_struct, int noteID);
static void ctl_mode_event(tmdy_struct_ex_t *tmdy_struct, int type, int trace, long arg1, long arg2);
static char *channel_instrum_name(tmdy_struct_ex_t *tmdy_struct, int ch);
static int get_reverb_level(tmdy_struct_ex_t *tmdy_struct, int ch);
static int get_chorus_level(tmdy_struct_ex_t *tmdy_struct, int ch);
static void playmidi_output_changed(tmdy_struct_ex_t *tmdy_struct, int play_state);
static Instrument *play_midi_load_instrument(tmdy_struct_ex_t *tmdy_struct, int dr, int bk, int prog);
static void midi_program_change(tmdy_struct_ex_t *tmdy_struct, int ch, int prog);
static void free_voice(tmdy_struct_ex_t *tmdy_struct, int v);
static void play_midi_setup_drums(tmdy_struct_ex_t *tmdy_struct, int ch,int note);

/* For stream player */
static void playmidi_stream_init(tmdy_struct_ex_t *tmdy_struct);
static void playmidi_tmr_reset(tmdy_struct_ex_t *tmdy_struct);
static int play_event(tmdy_struct_ex_t *tmdy_struct, MidiEvent *ev);

static void dup_tone_bank_element(tmdy_struct_ex_t *tmdy_struct, int,int,int);
static void free_tone_bank_element(tmdy_struct_ex_t *tmdy_struct, int,int,int);

static void recompute_voice_filter(tmdy_struct_ex_t *tmdy_struct, int);
static int compute_data(tmdy_struct_ex_t *tmdy_struct, int32 count);

#define PM TMDY_PLAYMIDI


#undef timidity_mutex_lock
#undef timidity_mutex_unlock
#define timidity_mutex_lock(_m) 
#define timidity_mutex_unlock(_m)
